==> entidades-1.0.4.tgz: package/src/models/productos.js <==
var neo4j = require('neo4j-driver').v1
var driver = neo4j.driver("bolt://localhost:7687", neo4j.auth.basic("neo4j", "admin"))
var session = driver.session()


exports.initializeProductos = function () {
    return session.run("CREATE CONSTRAINT ON (producto:Producto) ASSERT producto.idProducto IS UNIQUE")
}

exports.getProductos = function () {
    return session
        .run("MATCH (p:Producto) RETURN p")
        .then((result) => {
            return Promise.resolve(result.records.map((producto) => producto._fields[0].properties))
        })
}

exports.deleteAll = function () {
    return session
        .run("MATCH(p:Producto) DETACH DELETE p")
        .then(result => {
            return Promise.resolve(result.records.map((producto) => producto._fields[0].properties))
        })
}

exports.getProducto = function (idProducto) {
    return session
        .run("MATCH (p:Producto {idProducto: '" + idProducto + "'}) RETURN p")
        .then(result => {
            return Promise.resolve(
                result.records[0]._fields[0].properties
            )
        })
}

exports.updateProducto = function (producto) {
    var asignaciones = ""
    Object.getOwnPropertyNames(producto).forEach((nombrePropiedad) => {
        if (nombrePropiedad !== "idProducto") {
            var eventualApostrofe = typeof(producto[nombrePropiedad]) === "string" ? "'" : ""
            var eventualComa = asignaciones ? ", " : ""
            asignaciones += eventualComa + "p." + nombrePropiedad + " = " + eventualApostrofe + producto[nombrePropiedad] + eventualApostrofe
        }
    })
    if (asignaciones) {
        var query = "MATCH (p:Producto {idProducto: '" + producto.idProducto + "'}) SET " + asignaciones
        return session
            .run(query)
            .then(result => {
                return Promise.resolve({
                    producto: result.records.map((producto) => producto._fields[0].properties)
                })

            })
    }
}

exports.addProducto = function (producto) {
    return session
        .run("CREATE (p:Producto {idProducto: '" + producto.idProducto + "' })")
        .then(() => {
            exports.updateProducto(producto)
            return Promise.resolve({
                result: "Producto agregado correctamente"
            })
        })
        .catch(function (err) {
            done(err)
        })
}

exports.deleteProducto = function (idProducto) {
    return session
        .run("MATCH (p:Producto { idProducto: '" + idProducto + "' }) DELETE p")
        .then(() => {
            return Promise.resolve({
                result: "Producto borrado correctamente"
            })
        })
}

==> entidades-1.0.7.tgz: package/src/models/productos.js <==
var neo4j = require('neo4j-driver').v1
var driver = neo4j.driver("bolt://localhost:7687", neo4j.auth.basic("neo4j", "admin"))
var session = driver.session()


exports.initializeProductos = function () {
    return session.run("CREATE CONSTRAINT ON (producto:Producto) ASSERT producto.idProducto IS UNIQUE")
}

exports.getProductos = function () {
    return session
        .run("MATCH (p:Producto) RETURN p")
        .then((result) => {
            return Promise.resolve(result.records.map((producto) => producto._fields[0].properties))
        })
}

exports.deleteAll = function () {
    return session
        .run("MATCH(p:Producto) DETACH DELETE p")
        .then(result => {
            return Promise.resolve(result.records.map((producto) => producto._fields[0].properties))
        })
}

exports.getProducto = function (idProducto) {
    return session
        .run("MATCH (p:Producto {idProducto: '" + idProducto + "'}) RETURN p")
        .then(result => {
            return Promise.resolve(
                result.records[0]._fields[0].properties
            )
        })
}

exports.updateProducto = function (producto) {
    var asignaciones = ""
    Object.getOwnPropertyNames(producto).forEach((nombrePropiedad) => {
        if (nombrePropiedad !== "idProducto" || nombrePropiedad !== "cantidad") {
            var eventualApostrofe = typeof(producto[nombrePropiedad]) === "string" ? "'" : ""
            var eventualComa = asignaciones ? ", " : ""
            asignaciones += eventualComa + "p." + nombrePropiedad + " = " + eventualApostrofe + producto[nombrePropiedad] + eventualApostrofe
        }
    })
    if (asignaciones) {
        var query = "MATCH (p:Producto {idProducto: '" + producto.idProducto + "'}) SET " + asignaciones
        return session
            .run(query)
            .then(result => {
                return Promise.resolve({
                    producto: result.records.map((producto) => producto._fields[0].properties)
                })

            })
    }
}

exports.addProducto = function (producto) {
    return session
        .run("CREATE (p:Producto {idProducto: '" + producto.idProducto + "' })")
        .then(() => {
            exports.updateProducto(producto)
            return Promise.resolve({
                result: "Producto agregado correctamente"
            })
        })
        .catch(function (err) {
            done(err)
        })
}

exports.deleteProducto = function (idProducto) {
    return session
        .run("MATCH (p:Producto { idProducto: '" + idProducto + "' }) DELETE p")
        .then(() => {
            return Promise.resolve({
                result: "Producto borrado correctamente"
            })
        })
}
